pub enum MemInitError {
NoHugePageFound,
ImageMetadata(Error),
ImageRewind(Error),
ImageWriteIncomplete,
ImageRead(Error),
OffsetCheckOverflow,
ImagePlacementOverflow,
}Expand description
Error that may occur when allocating and configuring enclave memory.
Variants
NoHugePageFound
A valid combination of hugepages could not be found for the requested size.
ImageMetadata(Error)
Unable to retrieve image metadata.
ImageRewind(Error)
Unable to rewind image to beginning of image file.
ImageWriteIncomplete
Unable to write total image file to memory regions.
ImageRead(Error)
Unable to read bytes from image file.
OffsetCheckOverflow
Overflow when checking if memory region write was greater than image offset.
ImagePlacementOverflow
Overflow when calculating end of image region in guest memory.